==> actions-recorder-1.4.0-alpha1.tgz: package/lib/app/todolist.js <==
var Immutable, React, a, actions, classnames, div, input, onAdd, ref, render, repo;

React = require("react");

Immutable = require("immutable");

classnames = require("classnames");

actions = require("../actions");

ref = React.DOM, div = ref.div, a = ref.a, input = ref.input;

repo = 'https://github.com/teambition/actions-recorder';

module.exports = React.createClass({
  displayName: "app-todolist",
  propTypes: {
    store: React.PropTypes.instanceOf(Immutable.List)
  },
  onAdd: onAdd = function() {
    return actions.add();
  },
  rendeTask: function(task) {
    var checkboxClassName, onRemove, onToggle, onUpdate;
    onToggle = function() {
      return actions.toggle(task.get("id"));
    };
    onUpdate = function(event) {
      return actions.update(task.get("id"), event.target.value);
    };
    onRemove = function() {
      return actions.remove(task.get("id"));
    };
    checkboxClassName = classnames("checkbox", {
      "is-checked": task.get("done")
    });
    return div({
      className: "todolist-task line",
      key: task.get("id")
    }, div({
      className: checkboxClassName,
      onClick: onToggle
    }), input({
      type: "text",
      value: task.get("text"),
      onChange: onUpdate
    }), div({
      className: "button is-danger",
      onClick: onRemove
    }, "Remove"));
  },
  renderNote: function() {
    return div({
      className: 'note'
    }, a({
      href: repo
    }, "Demo of actions-recorder, find more on GitHub."));
  },
  render: render = function() {
    return div({
      className: "app-todolist"
    }, this.renderNote(), div({
      className: "todolist-table"
    }, this.props.store.map(this.rendeTask)), div({
      className: "todolist-footer"
    }, div({
      className: "button is-attract",
      onClick: this.onAdd
    }, "Add")));
  }
});

==> actions-recorder-1.6.0-alpha1.tgz: package/lib/app/todolist.js <==
var Immutable, React, a, actions, classnames, div, input, onAdd, ref, render, repo;

React = require("react");

Immutable = require("immutable");

classnames = require("classnames");

actions = require("../actions");

ref = React.DOM, div = ref.div, a = ref.a, input = ref.input;

repo = 'https://github.com/teambition/actions-recorder';

module.exports = React.createClass({
  displayName: "app-todolist",
  propTypes: {
    store: React.PropTypes.instanceOf(Immutable.List).isRequired
  },
  onAdd: onAdd = function() {
    return actions.add();
  },
  rendeTask: function(task) {
    var checkboxClassName, onRemove, onToggle, onUpdate;
    onToggle = function() {
      return actions.toggle(task.get("id"));
    };
    onUpdate = function(event) {
      return actions.update(task.get("id"), event.target.value);
    };
    onRemove = function() {
      return actions.remove(task.get("id"));
    };
    checkboxClassName = classnames("checkbox", {
      "is-checked": task.get("done")
    });
    return div({
      className: "todolist-task line",
      key: task.get("id")
    }, div({
      className: checkboxClassName,
      onClick: onToggle
    }), input({
      type: "text",
      value: task.get("text"),
      onChange: onUpdate
    }), div({
      className: "button is-danger",
      onClick: onRemove
    }, "Remove"));
  },
  renderNote: function() {
    return div({
      className: 'note'
    }, a({
      href: repo
    }, "Demo of actions-recorder, find more on GitHub."));
  },
  render: render = function() {
    return div({
      className: "app-todolist"
    }, this.renderNote(), div({
      className: "todolist-table"
    }, this.props.store.map(this.rendeTask)), div({
      className: "todolist-footer"
    }, div({
      className: "button is-attract",
      onClick: this.onAdd
    }, "Add")));
  }
});
